# Samgis LISA

LISA modules for [SamGIS](https://trinca.tornidor.com/projects/lisa-adapted-for-samgis) project.

See also:
- [samgis-core](https://pypi.org/project/samgis_core/)
- [samgis-web](https://pypi.org/project/samgis_web/)
